from django.db import models
from django.utils.translation import gettext_lazy as _
from django.core.validators import MinValueValidator


class Metric(models.Model):
    class Gender(models.TextChoices):
        MALE = 'M', _('Male')
        FEMALE = 'F', _('Female')

    user = models.OneToOneField('user.User', on_delete=models.CASCADE)
    gender = models.CharField(
        max_length=1,
        choices=Gender.choices,
        default=Gender.MALE,
        blank=False,
    )
    weight = models.FloatField(blank=False, validators=[MinValueValidator(0.0)], default=0.0)
    height = models.FloatField(blank=False, validators=[MinValueValidator(0.0)], default=0.0)
    birth_date = models.DateField(blank=False, null=False, default='2000-01-01')

    def __str__(self):
        return f"Gender: {self.gender}, Weight: {self.weight}, Height: {self.height}, Birth date: {self.birth_date}"

    class Meta:
        db_table = 'metric_table'
